@@ -13,6 +13,8 @@ from .postgres_server import QPostgresServer
 from .imap_server import QIMAPServer
 from .redis_server import QRedisServer
 from .mysql_server import QMysqlServer
+from .mssql_server import QMSSQLServer
+from .elastic_server import QElasticServer
 from .vnc_server import QVNCServer
 from .qbsniffer import QBSniffer
 from .helper import server_arguments, clean_all, kill_servers, get_free_port, close_port_wrapper, kill_server_wrapper, setup_logger, disable_logger, postgres_class, get_running_servers, set_local_vars
