@@ -3,7 +3,7 @@
 from warnings import filterwarnings
 filterwarnings(action='ignore', module='.*OpenSSL.*')
 
-from honeypots import QDNSServer, QFTPServer, QHTTPProxyServer, QHTTPServer, QHTTPSServer, QIMAPServer, QMysqlServer, QPOP3Server, QPostgresServer, QRedisServer, QSMBServer, QSMTPServer, QSOCKS5Server, QSSHServer, QTelnetServer, QVNCServer, server_arguments, clean_all, postgres_class, setup_logger, QBSniffer, get_running_servers
+from honeypots import QDNSServer, QFTPServer, QHTTPProxyServer, QHTTPServer, QHTTPSServer, QIMAPServer, QMysqlServer, QPOP3Server, QPostgresServer, QRedisServer, QSMBServer, QSMTPServer, QSOCKS5Server, QSSHServer, QTelnetServer, QVNCServer, QMSSQLServer, QElasticServer, server_arguments, clean_all, postgres_class, setup_logger, QBSniffer, get_running_servers
 from time import sleep
 from atexit import register
 from argparse import ArgumentParser
@@ -15,7 +15,7 @@ from uuid import uuid4
 from json import JSONEncoder, dumps, load
 
 
-all_servers = ['QDNSServer', 'QFTPServer', 'QHTTPProxyServer', 'QHTTPServer', 'QHTTPSServer', 'QIMAPServer', 'QMysqlServer', 'QPOP3Server', 'QPostgresServer', 'QRedisServer', 'QSMBServer', 'QSMTPServer', 'QSOCKS5Server', 'QSSHServer', 'QTelnetServer', 'QVNCServer']
+all_servers = ['QDNSServer', 'QFTPServer', 'QHTTPProxyServer', 'QHTTPServer', 'QHTTPSServer', 'QIMAPServer', 'QMysqlServer', 'QPOP3Server', 'QPostgresServer', 'QRedisServer', 'QSMBServer', 'QSMTPServer', 'QSOCKS5Server', 'QSSHServer', 'QTelnetServer', 'QVNCServer', 'QElasticServer', 'QMSSQLServer']
 
 temp_honeypots = []
 
@@ -69,7 +69,7 @@ if __name__ == "__main__":
             sleep(2)
             uuid = 'honeypotslogger' + '_' + 'main' + '_' + str(uuid4())[:8]
             logs = setup_logger(uuid, ARGV.config, True)
-            if type(honeypots) == {}:
+            if isinstance(honeypots, {}):
                 for honeypot in honeypots.items():
                     if "port" in honeypots[honeypot]:
                         for _honeypot in all_servers:
@@ -83,7 +83,7 @@ if __name__ == "__main__":
                                 x = globals()[_honeypot](config=ARGV.config)
                                 x.run_server(process=True)
                                 temp_honeypots.append(x)
-            if type(honeypots) == []:
+            if isinstance(honeypots, []):
                 for server in honeypots.split(','):
                     if ":" in server:
                         for honeypot in all_servers:
